@@ -75,7 +75,7 @@ class Client(object):
         3: "s"
     }
 
-    def __init__(self, host, port, hadoop_version=Namenode.DEFAULT_VERSION, use_trash=False):
+    def __init__(self, host, port=Namenode.DEFAULT_PORT, hadoop_version=Namenode.DEFAULT_VERSION, use_trash=False):
         '''
         :param host: Hostname or IP address of the NameNode
         :type host: string
@@ -797,7 +797,7 @@ class Client(object):
         return data[max(0, len(data)-1024):len(data)]
 
     def test(self, path, exists=False, directory=False, zero_length=False):
-        '''Test if a paht exist, is a directory or has zero length
+        '''Test if a path exist, is a directory or has zero length
 
         :param path: Path to test
         :type path: string
